==> 0.0.4.tar.gz: lib/package/swipe_cell.dart <==
import 'package:flutter/material.dart';

class MillSwipeCell extends StatefulWidget {
  MillSwipeCell({
    Key key,
    @required this.child,
    this.suffixs = const [],
    this.prefixs = const [],
  }) : super(key: key);

  final Widget child;
  final List<Widget> suffixs;
  final List<Widget> prefixs;
  _MillSwipeCell createState() => _MillSwipeCell();
}

class _MillSwipeCell extends State<MillSwipeCell> {
  ScrollController _controller = new ScrollController();
  List items = new List<String>.generate(20, (i) => "Item ${i + 1}");
  double _dur = 0.0;
  double _footMaxWidth = 400.0;
  double _preMaxWidth = 400.0;
  final GlobalKey fKey = GlobalKey();
  final GlobalKey sKey = GlobalKey();
  int _startType = 0;

  @override
  void initState() {
    super.initState();
    _controller.addListener(() {});
  }

  _drag(details) {
    double dx = details.delta.dx;
    int pl = widget.prefixs.length;
    int sl = widget.suffixs.length;
    if (_dur > 1 && pl > 0) {
      _preMaxWidth = _getPreWidth();
    } else if (sl > 0) {
      _footMaxWidth = _getFootWidth();
    }

    if (_dur == 0 && (dx > 0 && pl == 0 || dx < 0 && sl == 0)) {
      return false;
    }

    setState(() {
      if (pl == 0 && _dur > 0 || _dur < 0 && sl == 0) {
        _dur = 0;
      } else if (_dur == 0) {
        _setDur(dx);
      } else if (_dur < 0) {
        if (dx <= 0 && _dur < -(_footMaxWidth / 2)) {
          _dur = -(_footMaxWidth);
        } else if (dx > 0 && _dur > -20) {
          _dur = 0;
        } else {
          _setDur(dx);
        }
      } else {
        if (dx >= 0 && _dur > _preMaxWidth / 2) {
          _dur = _preMaxWidth;
        } else if (dx < 0 && _dur < 10) {
          _dur = 0;
        } else {
          _setDur(dx);
        }
      }
    });
  }

  _setDur(dx) {
    if (_startType == 1 && _dur + dx > 0) {
      _dur = 0;
    } else if (_startType == 2 && _dur + dx < 0) {
      _dur = 0;
    } else {
      _dur += dx;
    }
  }

  _dragend(details) {
    setState(() {
      if (_dur < 0 && _dur <= -(_footMaxWidth / 2)) {
        _dur = -(_footMaxWidth);
        _startType = 1;
      } else if (_dur < 0 && _dur > -(_footMaxWidth / 2)) {
        _dur = 0;
        _startType = 0;
      } else if (_dur > 0 && _dur >= _preMaxWidth / 2) {
        _dur = _preMaxWidth;
        _startType = 2;
      } else if (_dur > 0 && _dur < _preMaxWidth / 2) {
        _dur = 0;
        _startType = 0;
      } else {
        _startType = 0;
      }
    });
  }

  _getFootWidth() {
    if (fKey.currentContext.size != null) {
      return fKey.currentContext.size.width;
    } else {
      return widget.suffixs.length * 60;
    }
  }

  _getPreWidth() {
    if (sKey.currentContext.size != null) {
      return sKey.currentContext.size.width;
    } else {
      return widget.prefixs.length * 60;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      overflow: Overflow.visible,
      children: [
        Stack(
          children: [
            Row(
              mainAxisAlignment:
                  _dur > 0 ? MainAxisAlignment.start : MainAxisAlignment.end,
              children: [
                Offstage(
                  offstage: _dur <= 0,
                  child: Transform.translate(
                    offset: Offset(_dur - _preMaxWidth, 0.0),
                    child: Container(
                      key: sKey,
                      child: Row(
                        children: widget.prefixs,
                      ),
                    ),
                  ),
                ),
                Offstage(
                  offstage: _dur > 0,
                  child: Transform.translate(
                    offset: Offset(_footMaxWidth + _dur, 0.0),
                    child: Container(
                      key: fKey,
                      child: Row(
                        children: widget.suffixs,
                      ),
                    ),
                  ),
                )
              ],
            )
          ],
        ),
        Positioned(
          child: Transform.translate(
            offset: Offset(_dur, 0.0),
            child: GestureDetector(
              onHorizontalDragUpdate: _drag,
              onHorizontalDragEnd: _dragend,
              child: Container(
                width: double.infinity,
                child: widget.child,
              ),
            ),
          ),
        ),
      ],
    );
  }
}

==> 0.0.6.tar.gz: lib/package/swipe_cell.dart <==
import 'package:flutter/material.dart';

class MillSwipeCell extends StatefulWidget {
  MillSwipeCell({
    Key key,
    @required this.child,
    this.suffixs = const [],
    this.prefixs = const [],
  }) : super(key: key);

  final Widget child;
  final List<Widget> suffixs;
  final List<Widget> prefixs;
  _MillSwipeCell createState() => _MillSwipeCell();
}

class _MillSwipeCell extends State<MillSwipeCell> {
  ScrollController _controller = new ScrollController();
  double _dur = 0.0;
  double _footMaxWidth = 400.0;
  double _preMaxWidth = 400.0;
  final GlobalKey fKey = GlobalKey();
  final GlobalKey sKey = GlobalKey();
  int _startType = 0;

  @override
  void initState() {
    super.initState();
    _controller.addListener(() {});
  }

  _drag(details) {
    double dx = details.delta.dx;
    int pl = widget.prefixs.length;
    int sl = widget.suffixs.length;
    if (_dur > 1 && pl > 0) {
      _preMaxWidth = _getPreWidth();
    } else if (sl > 0) {
      _footMaxWidth = _getFootWidth();
    }

    if (_dur == 0 && (dx > 0 && pl == 0 || dx < 0 && sl == 0)) {
      return false;
    }

    setState(() {
      if (pl == 0 && _dur > 0 || _dur < 0 && sl == 0) {
        _dur = 0;
      } else if (_dur == 0) {
        _setDur(dx);
      } else if (_dur < 0) {
        if (dx <= 0 && _dur <= -_footMaxWidth) {
          _dur = -(_footMaxWidth);
        } else if (dx > 0 && _dur > -20) {
          _dur = 0;
        } else {
          _setDur(dx);
        }
      } else {
        if (dx >= 0 && _dur >= _preMaxWidth) {
          _dur = _preMaxWidth;
        } else if (dx < 0 && _dur < 10) {
          _dur = 0;
        } else {
          _setDur(dx);
        }
      }
    });
  }

  _setDur(dx) {
    if (_startType == 1 && _dur + dx > 0) {
      _dur = 0;
    } else if (_startType == 2 && _dur + dx < 0) {
      _dur = 0;
    } else {
      _dur += dx;
    }
  }

  _dragend(details) {
    setState(() {
      if (_startType == 0) {
        if (_dur <= -20) {
          _dur = -(_footMaxWidth);
          _startType = 1;
        } else if (_dur >= 20) {
          _dur = _preMaxWidth;
          _startType = 2;
        } else {
          _dur = 0;
        }
      }

      if (_startType == 1) {
        if (_dur > -_footMaxWidth * 0.9) {
          _dur = 0;
          _startType = 0;
        } else {
          _dur = -(_footMaxWidth);
        }
      }

      if (_startType == 2) {
        if (_dur < _preMaxWidth * 0.9) {
          _dur = 0;
          _startType = 0;
        } else {
          _dur = _preMaxWidth;
        }
      }
    });
  }

  _getFootWidth() {
    if (fKey.currentContext.size != null) {
      return fKey.currentContext.size.width;
    } else {
      return widget.suffixs.length * 60;
    }
  }

  _getPreWidth() {
    if (sKey.currentContext.size != null) {
      return sKey.currentContext.size.width;
    } else {
      return widget.prefixs.length * 60;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      fit: StackFit.loose,
      overflow: Overflow.clip,
      children: [
        Stack(
          children: [
            Row(
              mainAxisAlignment:
                  _dur > 0 ? MainAxisAlignment.start : MainAxisAlignment.end,
              children: [
                Offstage(
                  offstage: _dur <= 0,
                  child: Transform.translate(
                    offset: Offset(_dur - _preMaxWidth, 0.0),
                    child: Container(
                      key: sKey,
                      child: Row(
                        children: widget.prefixs,
                      ),
                    ),
                  ),
                ),
                Offstage(
                  offstage: _dur > 0,
                  child: Transform.translate(
                    offset: Offset(_footMaxWidth + _dur, 0.0),
                    child: Container(
                      key: fKey,
                      child: Row(
                        children: widget.suffixs,
                      ),
                    ),
                  ),
                )
              ],
            )
          ],
        ),
        Positioned(
          child: Transform.translate(
            offset: Offset(_dur, 0.0),
            child: GestureDetector(
              onHorizontalDragUpdate: _drag,
              onHorizontalDragEnd: _dragend,
              child: Container(
                width: double.infinity,
                child: widget.child,
              ),
            ),
          ),
        ),
      ],
    );
  }
}
